from setuptools import setup, find_packages

setup(
    name="gigaml",
    version="0.0.1",
    author="gigaml",
    author_email="founders@giga.do",
    description="A placeholder package for gigaml",
    packages=find_packages(),
)

